NIMB
====

NIMB IRC Matrix Bridge (NIMB) is a simple tool that can establish a
bridge between multiple IRC channels and Matrix rooms.

NIMB can join multiple IRC and Matrix channels/rooms simultaneously.
Whenever NIMB finds a new message posted to any channel/room, it
forwards that message to all other channels/rooms NIMB has joined.

Visit https://github.com/susam/nimb for more details.
